@@ -70,7 +70,6 @@ with the right hand side (*rhs*) in a tree (*tree*) is known as
 """
 import re
 
-from six import string_types
 
 from phrasetree.util import transitive_closure, invert_graph, raise_unorderable_types
 
@@ -260,7 +259,7 @@ class Production(object):
         :param rhs: The right-hand side of the new ``Production``.
         :type rhs: sequence(Nonterminal and terminal)
         """
-        if isinstance(rhs, string_types):
+        if isinstance(rhs, str):
             raise TypeError(
                 'production right hand side should be a list, ' 'not a string'
             )
@@ -1126,7 +1125,7 @@ def read_grammar(input, nonterm_parser, probabilistic=False, encoding=None):
     """
     if encoding is not None:
         input = input.decode(encoding)
-    if isinstance(input, string_types):
+    if isinstance(input, str):
         lines = input.split('\n')
     else:
         lines = input
