@@ -749,6 +749,10 @@ class Tree(list):
     def from_list(L):
         if isinstance(L, str):
             return L
+        while len(L) == 1:
+            L = L[0]
+            if isinstance(L, str):
+                return L
         return Tree(L[0], [Tree.from_list(child) for child in L[1]])
 
     def __repr__(self):
@@ -1554,7 +1558,8 @@ def demo():
     print("Convert bracketed string into tree:")
     print(t)
     print(t.__repr__())
-    print(Tree.from_list(['S', [['NP', [['DT', ['the']], ['NN', ['cat']]]], ['VP', [['VBD', ['ate']], ['NP', [['DT', ['a']], ['NN', ['cookie']]]]]]]]))
+    print(Tree.from_list(['S', [['NP', [['DT', ['the']], ['NN', ['cat']]]],
+                                ['VP', [['VBD', ['ate']], ['NP', [['DT', ['a']], ['NN', ['cookie']]]]]]]]))
 
     print("Display tree properties:")
     print(t.label())  # tree's constituent type
