@@ -5,32 +5,18 @@
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-import sys
 import inspect
 import locale
-import re
-import types
-import textwrap
-import pydoc
-import bisect
 import os
-
+import pydoc
+import re
+import sys
+import textwrap
+from collections import defaultdict, deque
 from itertools import islice, chain, combinations
 from pprint import pprint
-from collections import defaultdict, deque
 from sys import version_info
 
-from six import class_types, string_types, text_type
-from six.moves.urllib.request import (
-    build_opener,
-    install_opener,
-    getproxies,
-    ProxyHandler,
-    ProxyBasicAuthHandler,
-    ProxyDigestAuthHandler,
-    HTTPPasswordMgrWithDefaultRealm,
-)
-
 
 ######################################################################
 # Helper for Handling Slicing
@@ -103,46 +89,6 @@ def slice_bounds(sequence, slice_obj, allow_step=False):
     return start, stop
 
 
-######################################################################
-# Short usage message
-######################################################################
-
-
-def usage(obj, selfname='self'):
-    str(obj)  # In case it's lazy, this will load it.
-
-    if not isinstance(obj, class_types):
-        obj = obj.__class__
-
-    print('%s supports the following operations:' % obj.__name__)
-    for (name, method) in sorted(pydoc.allmethods(obj).items()):
-        if name.startswith('_'):
-            continue
-        if getattr(method, '__deprecated__', False):
-            continue
-
-        if sys.version_info[0] >= 3:
-            getargspec = inspect.getfullargspec
-        else:
-            getargspec = inspect.getargspec
-        args, varargs, varkw, defaults = getargspec(method)[:4]
-        if (
-                args
-                and args[0] == 'self'
-                and (defaults is None or len(args) > len(defaults))
-        ):
-            args = args[1:]
-            name = '%s.%s' % (selfname, name)
-        argspec = inspect.formatargspec(args, varargs, varkw, defaults)
-        print(
-            textwrap.fill(
-                '%s%s' % (name, argspec),
-                initial_indent='  - ',
-                subsequent_indent=' ' * (len(name) + 5),
-            )
-        )
-
-
 ##########################################################################
 # IDLE
 ##########################################################################
@@ -262,21 +208,6 @@ def re_show(regexp, string, left="{", right="}"):
     print(re.compile(regexp, re.M).sub(left + r"\g<0>" + right, string.rstrip()))
 
 
-##########################################################################
-# READ FROM FILE OR STRING
-##########################################################################
-
-# recipe from David Mertz
-def filestring(f):
-    if hasattr(f, 'read'):
-        return f.read()
-    elif isinstance(f, string_types):
-        with open(f, 'r') as infile:
-            return infile.read()
-    else:
-        raise ValueError("Must be called with a filename or file-like object")
-
-
 ##########################################################################
 # Breadth-First Search
 ##########################################################################
@@ -302,70 +233,6 @@ def breadth_first(tree, children=iter, maxdepth=-1):
                 pass
 
 
-##########################################################################
-# Guess Character Encoding
-##########################################################################
-
-# adapted from io.py in the docutils extension module (http://docutils.sourceforge.net)
-# http://www.pyzine.com/Issue008/Section_Articles/article_Encodings.html
-
-
-def guess_encoding(data):
-    """
-    Given a byte string, attempt to decode it.
-    Tries the standard 'UTF8' and 'latin-1' encodings,
-    Plus several gathered from locale information.
-
-    The calling program *must* first call::
-
-        locale.setlocale(locale.LC_ALL, '')
-
-    If successful it returns ``(decoded_unicode, successful_encoding)``.
-    If unsuccessful it raises a ``UnicodeError``.
-    """
-    successful_encoding = None
-    # we make 'utf-8' the first encoding
-    encodings = ['utf-8']
-    #
-    # next we add anything we can learn from the locale
-    try:
-        encodings.append(locale.nl_langinfo(locale.CODESET))
-    except AttributeError:
-        pass
-    try:
-        encodings.append(locale.getlocale()[1])
-    except (AttributeError, IndexError):
-        pass
-    try:
-        encodings.append(locale.getdefaultlocale()[1])
-    except (AttributeError, IndexError):
-        pass
-    #
-    # we try 'latin-1' last
-    encodings.append('latin-1')
-    for enc in encodings:
-        # some of the locale calls
-        # may have returned None
-        if not enc:
-            continue
-        try:
-            decoded = text_type(data, enc)
-            successful_encoding = enc
-
-        except (UnicodeError, LookupError):
-            pass
-        else:
-            break
-    if not successful_encoding:
-        raise UnicodeError(
-            'Unable to decode input data. '
-            'Tried the following encodings: %s.'
-            % ', '.join([repr(enc) for enc in encodings if enc])
-        )
-    else:
-        return (decoded, successful_encoding)
-
-
 ##########################################################################
 # Remove repeated elements from a list deterministcally
 ##########################################################################
@@ -784,48 +651,6 @@ def binary_search_file(file, key, cache={}, cacheDepth=-1):
     return None
 
 
-######################################################################
-# Proxy configuration
-######################################################################
-
-
-def set_proxy(proxy, user=None, password=''):
-    """
-    Set the HTTP proxy for Python to download through.
-
-    If ``proxy`` is None then tries to set proxy from environment or system
-    settings.
-
-    :param proxy: The HTTP proxy server to use. For example:
-        'http://proxy.example.com:3128/'
-    :param user: The username to authenticate with. Use None to disable
-        authentication.
-    :param password: The password to authenticate with.
-    """
-    from nltk import compat
-
-    if proxy is None:
-        # Try and find the system proxy settings
-        try:
-            proxy = getproxies()['http']
-        except KeyError:
-            raise ValueError('Could not detect default proxy settings')
-
-    # Set up the proxy handler
-    proxy_handler = ProxyHandler({'https': proxy, 'http': proxy})
-    opener = build_opener(proxy_handler)
-
-    if user is not None:
-        # Set up basic proxy authentication if provided
-        password_manager = HTTPPasswordMgrWithDefaultRealm()
-        password_manager.add_password(realm=None, uri=proxy, user=user, passwd=password)
-        opener.add_handler(ProxyBasicAuthHandler(password_manager))
-        opener.add_handler(ProxyDigestAuthHandler(password_manager))
-
-    # Overide the existing url opener
-    install_opener(opener)
-
-
 ######################################################################
 # ElementTree pretty printing from http://www.effbot.org/zone/element-lib.htm
 ######################################################################
